/** BEGIN COPYRIGHT BLOCK
 * Copyright (C) 2001 Sun Microsystems, Inc.  Used by permission.
 * Copyright (C) 2005 Red Hat, Inc.
 * All rights reserved.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 * END COPYRIGHT BLOCK **/
/*********************************************************************
**
** NAME:
**   ux-config.h
**
** DESCRIPTION:
**   Administration Server Pre-installation Program
**
** NOTES:
**
** HISTORY:
** $Log: ux-config.h,v $
** Revision 1.5  2005/08/18 19:06:43  rmeggins
** Bug(s) fixed: 166273
** Bug Description: Admin Server: fix copyrights, licensing
** Reviewed by: Rob C. (Thanks!)
** Fix Description: I fixed all of the copyrights to files that needed them and licensed all of the files under the plain old GPL v2.  Blizzard told me that we cannot bundle/distribute Apache or our modules in the same package/tarball with the Apache binary, so we'll have to be careful about packaging/distribution, and may need to relicense files that "touch" Apache (mod_admserv, mod_nss).  Rob found a few places that I missed.  I also removed cfgstuff/rotate and adminserv/pumpkin.dat.
** Platforms tested: RHEL3
** Flag Day: yes
** Doc impact: no
** QA impact: should be covered by regular nightly and manual testing
** New Tests integrated into TET: none
**
** Revision 1.4  2005/07/12 20:34:48  rcritten
** Install an Apache-compatible configuration.
**
** Revision 1.3  2005/03/02 23:31:32  nhosoi
** [147535] Brand the Administration Server as "Fedora"
** Brand name: BrandX -> Fedora; Updated copyrights.
**
** Revision 1.2  2005/02/09 01:47:15  nhosoi
** bugzilla 147535: De-brand the Administration Server as "brandx"
** attachment (110836)
**
** Revision 1.1.1.1  2005/02/01 23:14:48  cvsadm
** Move Admin Server from branch to TRUNK
**
** Revision 1.1.1.3  2001/11/05 20:04:56  ahakim
** XXX AOL/SBS/NSCP Copyright XXX
**
** Revision 1.1.1.2  2000/04/05 21:23:39  miodrag
** added prepareUpgrade()
**
** Revision 1.1.1.1  1999/03/03 23:21:35  svbld
** importing admin41 closer to the trunk
**
** Revision 1.1.2.8  1998/01/29 21:58:28  pvo
** Bug 104973 - removal of Admin screen. Only work in Custom or reconfig mode.
**
** Revision 1.1.2.7  1998/01/09 03:47:58  pvo
** Various code changes/additions:
**   - ask Ldap questions in case of reconfiguring admin
**   - write DefaultAcceptLanguage
**   - Use createSection in place of addSection
**   - Write windows.jar to classpath.
**
** Revision 1.1.2.6  1997/12/12 21:55:10  pvo
** Various bug fixes.
**
** Revision 1.1.2.5  1997/12/02 04:29:22  pvo
** Support Silent Installation.
**
** Revision 1.1.2.4  1997/10/22 02:46:08  pvo
** Removed restore().
**
** Revision 1.1.2.3  1997/10/01 17:24:11  pvo
** Changed include path.
**
** Revision 1.1.2.2  1997/09/27 02:43:39  pvo
** Check in.
**
**
*********************************************************************/
#include "dialog.h"
#include "ux-util.h"
extern const char *DEFAULT_SYSUSER;
extern const char *DEFAULT_OLDROOT;

class AdminPreInstall:public DialogManager
{
public:

   AdminPreInstall(int, char **);
   ~AdminPreInstall();

    int init();

    int  start();
    void add (Dialog *);
    void addLast(Dialog *);
    void resetLast();
    void clear();
    int  cont();
    void setParent(void *);
    void *parent() const;

    InstallInfo *getInstallInfo() const
      { return _installInfo; }

    NSString verifyAdminPort(const char *port) const;
    NSString verifyAdminSysUser(const char *sysUser) const;
    NSString guessAdminSysUser() const;
    NSString verifyApacheDir(const char*) const;
    NSString getApacheRoot(const char *dir) const;

    void     setupServerAdmin();
    int  prepareUpgrade();

private:

   Bool             _runFromShell;
   NSString        _serverRoot;

   NSString        _infoFile;
   InstallInfo     *_installInfo;
   InstallInfo     *_adminInfo;

   NSString        _logFile;
   InstallLog      *_installLog;

   Bool _configured;
   Bool _reconfig;


   void getOptions(int argc, char **argv);
   void initDefaultConfig();
   int  doSilentInstall();
   void stopAdmin() const;
   int  updateAdmin() const;

};
