#
# BEGIN COPYRIGHT BLOCK
# Copyright (C) 2001 Sun Microsystems, Inc.  Used by permission.
# Copyright (C) 2005 Red Hat, Inc.
# All rights reserved.
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
#

# END COPYRIGHT BLOCK
#
#
# This makefile is used to grab all the components needed to build.
#
#
#

include $(NSROOT)/nsperl.mk

COMMA := ,
NULLSTRING :=
SPACE := $(NULLSTRING) # the space is between the ) and the #

RELTOOLS = $(ABS_ROOT)/reltools

#Temporary integration area components
INT_NMCSDK = 1
INT_ICU = 0
INT_ADMINUTIL = 0
INT_SETUPUTIL = 1
INT_LDAPSDK = 0
INT_ADMDOC = 0

#To control external build vs. internal build
BUILD_MODE = ext

#############################################
# NSPR Library
############################################

NSPR_RELDATE =  v4.4.1

NSPR_NSOBJDIR=$(NSOBJDIR_NAME)

ifeq ($(INT_NSPR), 1)
BASE_NSPR = $(INT_DIR)/nspr20/$(NSPR_RELDATE)/$(NSPR_NSOBJDIR)
else
BASE_NSPR = $(COMPONENTS_DIR)/nspr20/$(NSPR_RELDATE)/$(NSPR_NSOBJDIR)
endif

ifndef COMPONENT_PULL_METHOD
COMPONENT_PULL_METHOD=SYMLINK
endif

$(LIBNSPR): 
ifdef INTERNAL_BUILD
ifneq ($(ARCH), WINNT)
	$(PERL5) -I$(RELTOOLS) $(RELTOOLS)/ftp_puller.pl -method $(COMPONENT_PULL_METHOD) -objdir $(NSCP_DISTDIR)/nspr -componentdir $(BASE_NSPR) -files mdbinary.jar -unzip $(NSCP_DISTDIR)
	$(PERL5) -I$(RELTOOLS) $(RELTOOLS)/ftp_puller.pl -method $(COMPONENT_PULL_METHOD) -objdir $(NSCP_DISTDIR)/nspr -componentdir $(BASE_NSPR) -files mdheader.jar -unzip $(NSCP_DISTDIR)/include
else
	$(PERL5) -I$(RELTOOLS) $(RELTOOLS)/ftp_puller.pl -method FTP -objdir $(NSCP_DISTDIR)/nspr -componentdir $(BASE_NSPR) -files mdbinary.jar -unzip $(NSCP_DISTDIR)
	$(PERL5) -I$(RELTOOLS) $(RELTOOLS)/ftp_puller.pl -method FTP -objdir $(NSCP_DISTDIR)/nspr -componentdir $(BASE_NSPR) -files mdheader.jar -unzip $(NSCP_DISTDIR)/include
endif
else # INTERNAL_BUILD
	@if [ ! -f $@ ]; then echo $@ does not exist - please build or download it ; exit 1 ; fi
endif
###############################################
# DBM Library
##############################################

DBM_RELDATE = DBM_1_61_RTM

ifeq ($(INT_DBM), 1)
BASE_DBM = $(INT_DIR)/dbm/$(DBM_RELDATE)
else
BASE_DBM = $(COMPONENTS_DIR)/dbm/$(DBM_RELDATE)
endif

$(LIBDBM):
ifdef INTERNAL_BUILD
ifneq ($(ARCH), WINNT)
	$(PERL5) $(RELTOOLS)/ftp_puller.pl -method $(COMPONENT_PULL_METHOD) -objdir $(NSCP_DISTDIR)/dbm -componentdir $(BASE_DBM) -files xpheader.jar -unzip $(NSCP_DISTDIR)/include
	$(PERL5) $(RELTOOLS)/ftp_puller.pl -method $(COMPONENT_PULL_METHOD) -objdir $(NSCP_DISTDIR)/dbm -componentdir $(BASE_DBM)/$(NSOBJDIR_NAME) -files mdbinary.jar -unzip $(NSCP_DISTDIR)
else
	$(PERL5) $(RELTOOLS)/ftp_puller.pl -method FTP -objdir $(NSCP_DISTDIR)/dbm -componentdir $(BASE_DBM) -files xpheader.jar -unzip $(NSCP_DISTDIR)/include
	$(PERL5) $(RELTOOLS)/ftp_puller.pl -method FTP -objdir $(NSCP_DISTDIR)/dbm -componentdir $(BASE_DBM)/$(NSOBJDIR_NAME) -files mdbinary.jar -unzip $(NSCP_DISTDIR)
endif
else # INTERNAL_BUILD
	@if [ ! -f $@ ]; then echo $@ does not exist - please build or download it ; exit 1 ; fi
endif


################################################
# SECURITY LIBRARY
################################################

SECURITY_RELDATE = NSS_3_9_3_RTM

ifeq ($(INT_NSS), 1)
BASE_NSS = $(INT_DIR)/nss/$(SECURITY_RELDATE)
else
BASE_NSS = $(COMPONENTS_DIR)/nss/$(SECURITY_RELDATE)
endif

$(LIBSECURITY):
ifdef INTERNAL_BUILD
ifneq ($(ARCH), WINNT)
	$(PERL5) $(RELTOOLS)/ftp_puller.pl -method $(COMPONENT_PULL_METHOD) -objdir $(NSCP_DISTDIR)/nss -componentdir $(BASE_NSS) -files xpheader.jar -unzip $(NSCP_DISTDIR)/include
	$(PERL5) $(RELTOOLS)/ftp_puller.pl -method $(COMPONENT_PULL_METHOD) -objdir $(NSCP_DISTDIR)/nss -componentdir $(BASE_NSS)/$(NSOBJDIR_NAME) -files mdbinary.jar -unzip $(NSCP_DISTDIR)
else
	$(PERL5) $(RELTOOLS)/ftp_puller.pl -method FTP -objdir $(NSCP_DISTDIR)/nss -componentdir $(BASE_NSS) -files xpheader.jar -unzip $(NSCP_DISTDIR)/include
	$(PERL5) $(RELTOOLS)/ftp_puller.pl -method FTP -objdir $(NSCP_DISTDIR)/nss -componentdir $(BASE_NSS)/$(NSOBJDIR_NAME) -files mdbinary.jar -unzip $(NSCP_DISTDIR)
endif
else # INTERNAL_BUILD
	@if [ ! -f $@ ]; then echo $@ does not exist - please build or download it ; exit 1 ; fi
endif

##################################################
# ICU Library
#################################################

ICU_RELDATE = libicu_2_4/20040820

ICU_ROOT = $(NSCP_COMPDIR)/libicu
ICU_OBJDIR = $(NSOBJDIR_NAME)

ifeq ($(INT_ICU), 1)
BASE_ICU = $(INT_DIR)/libicu/$(ICU_RELDATE)/$(ICU_OBJDIR)
else
BASE_ICU = $(COMPONENTS_DIR)/libicu/$(ICU_RELDATE)/$(ICU_OBJDIR)
endif

$(LIBICU): 
ifdef INTERNAL_BUILD
ifneq ($(ARCH), WINNT)
	$(PERL5) $(RELTOOLS)/ftp_puller.pl -method $(COMPONENT_PULL_METHOD) -objdir $(ICU_ROOT)/$(ICU_OBJDIR) -componentdir $(BASE_ICU) -files include,lib,bin
else
	$(PERL5) $(RELTOOLS)/ftp_puller.pl -method FTP -objdir $(ICU_ROOT)/$(ICU_OBJDIR) -componentdir $(BASE_ICU) -files include,lib,bin
endif
else # INTERNAL_BUILD
	@if [ ! -f $@ ]; then echo $@ does not exist - please build or download it ; exit 1 ; fi
	chmod +x $(ICU_BINPATH)/*
endif

##############################################################
# SETUPUTIL
##############################################################

SETUPUTIL_RELDATE = 20050831
SETUPUTIL_FILE = setuputil.tar.gz
SETUPUTIL_COMPNAME = setuputil/7.1

SETUPUTIL_ROOT = $(NSCP_COMPDIR)/setuputil

SETUPUTIL_OBJDIR  = $(NSOBJDIR_NAME)

ifeq ($(BUILD_MODE), int)
ifeq ($(INT_SETUPUTIL), 1)
#intenal & integration
	BASE_SETUPUTIL = $(INT_DIR)/$(SETUPUTIL_COMPNAME)/$(SETUPUTIL_RELDATE)/$(SETUPUTIL_OBJDIR)
else
#intenal & components
	BASE_SETUPUTIL = $(COMPONENTS_DIR)/$(SETUPUTIL_COMPNAME)/$(SETUPUTIL_RELDATE)/$(SETUPUTIL_OBJDIR)
endif
else
#fedora
	BASE_SETUPUTIL = $(FED_COMPONENTS_DIR)/$(SETUPUTIL_COMPNAME)/$(SETUPUTIL_RELDATE)/$(SETUPUTIL_OBJDIR)
endif

SETUPUTIL_DEST = $(SETUPUTIL_ROOT)/$(SETUPUTIL_OBJDIR)

$(SETUPUTIL): 
ifdef INTERNAL_BUILD
ifneq ($(ARCH), WINNT)
	$(PERL5) $(RELTOOLS)/ftp_puller.pl -method $(COMPONENT_PULL_METHOD) -objdir $(SETUPUTIL_ROOT)/$(SETUPUTIL_OBJDIR) -componentdir $(BASE_SETUPUTIL) -files bin,include,lib
else
	$(PERL5) $(RELTOOLS)/ftp_puller.pl -method FTP -objdir $(SETUPUTIL_DEST)/temp -componentdir $(BASE_SETUPUTIL) -files $(SETUPUTIL_FILE) -unzip $(SETUPUTIL_DEST)
endif
else # INTERNAL_BUILD
	@if [ ! -f $@ ]; then echo $@ does not exist - please build or download it ; exit 1 ; fi
endif

################################################################
# ADMINUTIL Library
###############################################################

ADMINUTIL_SUF     = 71
ADMINUTIL_RELDATE = 20050721
ADMINUTIL_VERSION = $(ADMINUTIL_RELDATE)
ADMINUTIL_ROOT = $(NSCP_COMPDIR)/adminutil
ADMINUTIL_COMPNAME = adminutil/7.1

ADMINUTILOBJDIR = $(NSOBJDIR_NAME)

ifeq ($(BUILD_MODE), int)
ifeq ($(INT_ADMINUTIL), 1)
#intenal & integration
	BASE_ADMINUTIL = $(INT_DIR)/$(ADMINUTIL_COMPNAME)/$(ADMINUTIL_VERSION)/$(ADMINUTILOBJDIR)
else
#intenal & components
	BASE_ADMINUTIL = $(COMPONENTS_DIR)/$(ADMINUTIL_COMPNAME)/$(ADMINUTIL_VERSION)/$(ADMINUTILOBJDIR)
endif
else
#fedora
	BASE_ADMINUTIL = $(FED_COMPONENTS_DIR)/$(ADMINUTIL_COMPNAME)/$(ADMINUTIL_VERSION)/$(ADMINUTILOBJDIR)
endif


$(LIBADMINUTIL): 
ifdef INTERNAL_BUILD
ifneq ($(ARCH), WINNT)
	$(PERL5) $(RELTOOLS)/ftp_puller.pl -method $(COMPONENT_PULL_METHOD) -objdir $(ADMINUTIL_ROOT)/$(ADMINUTILOBJDIR) -componentdir $(BASE_ADMINUTIL) -files include,lib
else
	$(PERL5) $(RELTOOLS)/ftp_puller.pl -method FTP -objdir $(ADMINUTIL_ROOT)/$(ADMINUTILOBJDIR) -componentdir $(BASE_ADMINUTIL) -files include,lib
endif
else # INTERNAL_BUILD
	@if [ ! -f $@ ]; then echo $@ does not exist - please build or download it ; exit 1 ; fi
endif

################################################################
# DOCS
################################################################

ADMDOC_SUF     = 7.1$(BUILD_MODE)
ADMDOC_RELDATE = 20050309
ADMDOC_VERSION = $(ADMDOC_RELDATE)
ADMDOC_PATH = $(NSCP_COMPDIR)/admservdoc
ADMDOC_ABSPATH = $(ABS_ROOT)/components/admservdoc
ADMDOC_COMPNAME = adminservdoc/$(ADMDOC_SUF)
ADMDOC_ADMONLINEHELP = admserv_onlinehelp.zip
ADMDOC_CONSOLEONLINEHELP = console_onlinehelp.zip

ADMDOC_FILES = $(ADMDOC_ADMONLINEHELP),$(ADMDOC_CONSOLEONLINEHELP)

ADMDOC = $(addprefix $(ADMDOC_PATH)/, $(ADMDOC_FILES))

ifeq ($(INT_ADMDOC), 1)
BASE_ADMDOC = $(INT_DIR)/$(ADMDOC_COMPNAME)/$(ADMDOC_VERSION)
else
BASE_ADMDOC = $(COMPONENTS_DIR)/$(ADMDOC_COMPNAME)/$(ADMDOC_VERSION)
endif

ifeq ($(ARCH), WINNT)
ADMDOC_METHOD = FTP
else
ADMDOC_METHOD = $(COMPONENT_PULL_METHOD)
endif

$(ADMDOC): 
ifdef INTERNAL_BUILD
	$(PERL5) $(RELTOOLS)/ftp_puller.pl -method $(ADMDOC_METHOD) -objdir $(ADMDOC_PATH) -componentdir $(BASE_ADMDOC) -files $(ADMDOC_FILES)
endif

#############################################################
# LDAP C SDK Library
#############################################################

LDAP_RELDATE = v5.16
LDAP_SUF = 50
LDAP_VERSION = $(LDAP_RELDATE)

ifeq ($(INT_LDAPSDK), 1)
BASE_LDAPSDK = $(INT_DIR)/ldapsdk$(LDAP_SUF)/$(LDAP_VERSION)/$(NSOBJDIR_NAME)
else
BASE_LDAPSDK = $(COMPONENTS_DIR)/ldapsdk$(LDAP_SUF)/$(LDAP_VERSION)/$(NSOBJDIR_NAME)
endif

$(LIBLDAP):
ifdef INTERNAL_BUILD
ifneq ($(ARCH), WINNT)
	$(PERL5) $(RELTOOLS)/ftp_puller.pl -method $(COMPONENT_PULL_METHOD) -objdir $(LDAPSDK_BUILD_DIR) -componentdir $(BASE_LDAPSDK) -files lib,tools,include
else
	$(PERL5) $(RELTOOLS)/ftp_puller.pl -method FTP -objdir $(LDAPSDK_BUILD_DIR) -componentdir $(BASE_LDAPSDK) -files lib,tools,include
endif
else # INTERNAL_BUILD
	@if [ ! -f $@ ]; then echo $@ does not exist - please build or download it ; exit 1 ; fi
endif

###############################################################
# LDAP java classes 
##############################################################

LDAPJDK_VERSION = v4.17
LDAPJDK = ldapjdk.jar
LDAPJDK_COMP = ldapjdk41

ifeq ($(INT_LDAPJDK), 1)
BASE_LDAPJDK = $(INT_DIR)/$(LDAPJDK_COMP)/$(LDAPJDK_VERSION)
else
BASE_LDAPJDK = $(COMPONENTS_DIR)/$(LDAPJDK_COMP)/$(LDAPJDK_VERSION)
endif

ldapjdk:
ifdef INTERNAL_BUILD
	$(PERL5) $(RELTOOLS)/ftp_puller.pl -method FTP -objdir $(CLASS_DEST)/. -componentdir $(BASE_LDAPJDK)/$(NSOBJDIR_NAME) -files $(LDAPJDK)
else # INTERNAL_BUILD
	@if [ ! -f $(LDAPJDK_DIR)/$(LDAPJDK) ]; then echo $(LDAPJDK_DIR)/$(LDAPJDK) does not exist - please build or download it ; exit 1 ; fi
endif

#############################################################
# Console java classes 
#############################################################

NMCJDK_SUF =  71
NMCJDK_RELDATE = 20050831

NMCJDK_COMP = console/7.1

NMCJDK_VERSION = $(NMCJDK_RELDATE)

ifeq ($(INT_NMCSDK), 1)
BASE_NMCSDK = $(INT_DIR)/$(NMCJDK_COMP)/$(NMCJDK_VERSION)/$(NSOBJDIR_NAME)
else
BASE_NMCSDK = $(COMPONENTS_DIR)/$(NMCJDK_COMP)/$(NMCJDK_VERSION)/$(NSOBJDIR_NAME)
endif

NMCJDK_DIR = $(BASE_NMCSDK)/java

# since the jar files are packaged as is, they should not be symlink'ed.
NMCJDK_METHOD = FTP

nmcjdk:
ifdef INTERNAL_BUILD
	mkdir -p $(CLASS_DEST)
# grab the jar files
	$(PERL5) $(RELTOOLS)/ftp_puller.pl -method $(NMCJDK_METHOD) -objdir $(CLASS_DEST) -componentdir $(NMCJDK_DIR) -files base.jar,mcc$(NMCJDK_SUF).jar,mcc$(NMCJDK_SUF)_en.jar,nmclf$(NMCJDK_SUF).jar,nmclf$(NMCJDK_SUF)_en.jar,caplugin
# grab the startconsole program
	$(PERL5) $(RELTOOLS)/ftp_puller.pl -method $(NMCJDK_METHOD) -objdir $(CLASS_DEST) -componentdir $(BASE_NMCSDK) -files startconsole && chmod +x $(CLASS_DEST)/startconsole
else # INTERNAL_BUILD
	@if [ ! -f $(CONSOLE_JAR_DIR)/base.jar ]; then echo The console jar files are missing from $(CONSOLE_JAR_DIR) - please build or download them ; exit 1 ; fi
endif

#############################################################
# JSS java classes 
#############################################################

JSS_SDK_VERSION = JSS_3_5_1_RTM
JSSSDK = jss3.jar
XPCLASS = $(JSS_JAR_NAME)

ifeq ($(INT_JSS), 1)
BASE_JSS = $(INT_DIR)/jss/$(JSS_SDK_VERSION)
else
BASE_JSS = $(COMPONENTS_DIR)/jss/$(JSS_SDK_VERSION)
endif

jsssdk:
ifdef INTERNAL_BUILD
	mkdir -p $(CLASS_DEST)
	$(PERL5) -I$(RELTOOLS) $(RELTOOLS)/ftp_puller.pl -method FTP -objdir $(CLASS_DEST)/. -componentdir $(BASE_JSS) -files $(JSS_JAR_NAME)
else # INTERNAL_BUILD
	@if [ ! -f $(JSS_JAR_DIR)/$(JSS_JAR_NAME) ]; then echo The $(JSS_JAR_DIR)/$(JSS_JAR_NAME) file is missing - please build or download it ; exit 1 ; fi
endif


#############################################################
# JSS Support Library
#############################################################

JSSLIB = mdbinary.jar

BASE_JSSLIB = $(NSCP_COMPDIR)/jss/$(NSOBJDIR_NAME)

jsslib:
ifdef INTERNAL_BUILD
	$(PERL5) $(RELTOOLS)/ftp_puller.pl -method $(COMPONENT_PULL_METHOD) -objdir $(BASE_JSSLIB) -componentdir $(BASE_JSS)/${NSOBJDIR_NAME} -files ${JSSLIB} -unzip $(BASE_JSSLIB)
else # INTERNAL_BUILD
	@if [ ! -d $(JSS_LIBPATH) ]; then echo The $@ is not in $(JSS_LIBPATH) - please build or download it ; exit 1 ; fi
endif

# ANT java classes #######################################
#  (we use ant for building some Java code)
ifndef ANT_VERSION
  ANT_VERSION = 1.6.2
endif
ifndef ANT_COMP
  ANT_COMP = ant
endif
ANTJAR = ant.jar
ANTLAUNCHERJAR = ant-launcher.jar
ANT_FILES = $(ANTJAR) $(ANTLAUNCHERJAR)
ANT_RELEASE = $(COMPONENTS_DIR)
ANT_HOME = $(ANT_RELEASE)/$(ANT_COMP)/$(ANT_VERSION)
ANT_DIR = $(ANT_HOME)/lib
ANT_DEP = $(addprefix $(CLASS_DEST)/, $(ANT_FILES))
ANT_CP = $(subst $(SPACE),$(PATH_SEP),$(ANT_DEP))
ANT_PULL = $(subst $(SPACE),$(COMMA),$(ANT_FILES))

ifndef ANT_PULL_METHOD
ANT_PULL_METHOD = FTP
endif

$(ANT_DEP):
ifdef INTERNAL_BUILD
	mkdir -p $(CLASS_DEST)
	$(PERL5) $(RELTOOLS)/ftp_puller.pl -method FTP -objdir $(CLASS_DEST) \
		-componentdir $(ANT_DIR) -files $(ANT_PULL)
	-@if [ ! -f $@ ] ; \
	then echo "Error: could not get component ant files $@" ; \
	fi
else # INTERNAL_BUILD
endif

###########################################################

# mod_admserv #############################################
MOD_ADMSERV_RELDATE = 20050819

#BASE_MOD_ADMSERV = $(COMPONENTS_DIR)/mod_admserv/$(MOD_ADMSERV_RELDATE)/$(NSOBJDIR_NAME)
BASE_MOD_ADMSERV = $(INT_DIR)/mod_admserv/$(MOD_ADMSERV_RELDATE)/$(NSOBJDIR_NAME)

MOD_ADMSERV = $(MOD_ADMSERV_LIBPATH)/libmodadmserv.$(DLL_SUFFIX)

$(MOD_ADMSERV): 
ifdef INTERNAL_BUILD
	$(PERL5) $(RELTOOLS)/ftp_puller.pl -method $(COMPONENT_PULL_METHOD) \
		-objdir $(MOD_ADMSERV_BUILD_DIR) \
		-componentdir $(BASE_MOD_ADMSERV) -files lib
else # INTERNAL_BUILD
	@if [ ! -f $@ ]; then echo $@ does not exist - please build or download it ; exit 1 ; fi
endif

###########################################################

# mod_nss #############################################
MOD_NSS_RELDATE = 20050819

#BASE_MOD_NSS = $(COMPONENTS_DIR)/mod_nss/$(MOD_NSS_RELDATE)/$(NSOBJDIR_NAME)
BASE_MOD_NSS = $(INT_DIR)/mod_nss/$(MOD_NSS_RELDATE)/$(NSOBJDIR_NAME)

MOD_NSS = $(MOD_NSS_LIBPATH)/libmodnss.$(DLL_SUFFIX)

$(MOD_NSS): 
ifdef INTERNAL_BUILD
	$(PERL5) $(RELTOOLS)/ftp_puller.pl -method $(COMPONENT_PULL_METHOD) \
		-objdir $(MOD_NSS_BUILD_DIR) \
		-componentdir $(BASE_MOD_NSS) -files lib,bin
else # INTERNAL_BUILD
	@if [ ! -f $@ ]; then echo $@ does not exist - please build or download it ; exit 1 ; fi
endif

###########################################################
